@@ -58,6 +58,9 @@ extern "C" {
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 
 #if !defined(FALSE)
 #define FALSE 0
@@ -285,6 +288,7 @@ typedef enum {
 
 /* Global Malloc-Replacement API */
 int     MM_create(size_t size, const char *file);
+int     MM_permission(mode_t mode, uid_t owner, gid_t group);
 void    MM_destroy(void);
 int     MM_lock(mm_lock_mode mode);
 int     MM_unlock(void);
@@ -300,6 +304,7 @@ char   *MM_error(void);
 
 /* Standard Malloc-Style API */
 MM     *mm_create(size_t size, const char *file);
+int     mm_permission(MM *mm, mode_t mode, uid_t owner, gid_t group);
 void    mm_destroy(MM *mm);
 int     mm_lock(MM *mm, mm_lock_mode mode);
 int     mm_unlock(MM *mm);
@@ -316,6 +321,7 @@ void    mm_display_info(MM *mm);
 
 /* Low-Level Shared Memory API */
 void   *mm_core_create(size_t size, const char *file);
+int     mm_core_permission(void *core, mode_t mode, uid_t owner, gid_t group);
 void    mm_core_delete(void *core);
 size_t  mm_core_size(const void *core);
 int     mm_core_lock(const void *core, mm_lock_mode mode);
