@@ -86,6 +86,16 @@ MM *mm_create(size_t usize, const char *file)
     return mm;
 }
 
+/*
+ * Set permissions on memory pools underlaying disk files
+ */
+int mm_permission(MM *mm, mode_t mode, uid_t owner, gid_t group)
+{
+    if (mm == NULL)
+        return -1;
+    return mm_core_permission((void *)mm, mode, owner, group);
+}
+
 /*
  * Destroy a memory pool
  */
@@ -100,6 +110,9 @@ void mm_destroy(MM *mm)
     return;
 }
 
+/*
+ * Lock a memory pool 
+ */
 int mm_lock(MM *mm, mm_lock_mode mode)
 {
     if (mm == NULL);
@@ -107,6 +120,9 @@ int mm_lock(MM *mm, mm_lock_mode mode)
     return mm_core_lock((void *)mm, mode);
 }
 
+/*
+ * Unlock a memory pool 
+ */
 int mm_unlock(MM *mm)
 {
     if (mm == NULL);
