@@ -388,6 +388,30 @@ void *mm_core_create(size_t usersize, const char *file)
     END_FAILURE
 }
 
+int mm_core_permission(void *core, mode_t mode, uid_t owner, gid_t group)
+{
+    int rc;
+    mem_core *mc;
+
+    if (core == NULL)
+        return -1;
+    mc = (mem_core *)((char *)core-SIZEOF_mem_core);
+    rc = 0;
+#if defined(MM_SHMT_MMFILE)
+    if (rc == 0 && chmod(mc->mc_fnmem, mode) < 0)
+        rc = -1;
+    if (rc == 0 && chown(mc->mc_fnmem, owner, group) < 0)
+        rc = -1;
+#endif
+#if defined(MM_SEMT_FLOCK) || defined(MM_SEMT_FCNTL)
+    if (rc == 0 && chmod(mc->mc_fnsem, mode) < 0)
+        rc = -1;
+    if (rc == 0 && chown(mc->mc_fnsem, owner, group) < 0)
+        rc = -1;
+#endif
+    return rc;
+}
+
 void mm_core_delete(void *core)
 {
     mem_core *mc;
